/******************************************************************************
 * Copyright (c) 2016 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 ******************************************************************************/

package oracle.eclipse.tools.common.upgrade;

import java.util.ArrayList;
import java.util.List;
import java.util.Set;

import org.eclipse.core.resources.IFile;
import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.SubProgressMonitor;
import org.eclipse.jdt.core.IClasspathEntry;
import org.eclipse.jdt.core.IJavaProject;
import org.eclipse.jdt.core.JavaCore;

/**
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

public abstract class AbstractClasspathUpgradeParticipant

    extends AbstractProjectUpgradeParticipant
    
{
    public final boolean check( final IProject project ) 
        
        throws CoreException 
        
    {
        if( project.hasNature( JavaCore.NATURE_ID ) )
        {
            final IJavaProject jproject = JavaCore.create( project );
            
            for( IClasspathEntry cpe : jproject.getRawClasspath() )
            {
                if( check( jproject, cpe ) )
                {
                    return true;
                }
            }
        }
        
        return false;
    }
    
    @Override
    protected void prepare( final IProject project,
                            final Set<Action> actions )
    {
        final IFile f = project.getFile( IJavaProject.CLASSPATH_FILE_NAME );
        actions.add( new Action( Action.Type.EDIT, f ) );
    }

    public final void execute( final IProject project, 
                               final IProgressMonitor monitor ) 
    
        throws CoreException 
        
    {
        monitor.beginTask( "", 10 ); //$NON-NLS-1$
        
        try
        {
            if( project.hasNature( JavaCore.NATURE_ID ) )
            {
                final IJavaProject jproject = JavaCore.create( project );
                final IClasspathEntry[] oldcp = jproject.getRawClasspath();
                final List<Integer> entries = new ArrayList<Integer>();

                for( int i = 0; i < oldcp.length; i++ )
                {
                    if( check( jproject, oldcp[ i ] ) )
                    {
                        entries.add( i );
                    }
                }

                final IClasspathEntry[] newcp = new IClasspathEntry[ oldcp.length ];
                System.arraycopy( oldcp, 0, newcp, 0, oldcp.length );
                
                monitor.worked( 2 );
                
                final SubProgressMonitor submon = new SubProgressMonitor( monitor, 6 );
                submon.beginTask( "", entries.size() ); //$NON-NLS-1$
                
                try
                {
                    for( int position : entries )
                    {
                        execute( jproject, newcp, position );
                        submon.worked( 1 );
                    }
                }
                finally
                {
                    submon.done();
                }
                
                jproject.setRawClasspath( newcp, new SubProgressMonitor( monitor, 2 ) );
            }
        }
        finally
        {
            monitor.done();
        }
    }
    
    protected abstract boolean check( IJavaProject jproject,
                                      IClasspathEntry cpe )
    
        throws CoreException;
    
    protected abstract void execute( IJavaProject jproject,
                                     IClasspathEntry[] cp,
                                     int position )
    
        throws CoreException;

}
