/******************************************************************************
 * Copyright (c) 2016 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 ******************************************************************************/

package oracle.eclipse.tools.common.upgrade;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;

public interface IWorkspaceUpgradeParticipant 
{
    /**
     * This method is invoked by the upgrade framework to determine whether the
     * upgrade participant has any work to do. The implementation should be as
     * fast as possible since this method will be frequently invoked.
     * 
     * @return <code>true</code> if the upgrade participant has detected that
     *   some upgrade actions need to be taken on the workspace
     * @throws CoreException if failed for any reason
     */
    
    boolean check() throws CoreException;
    
    /**
     * This method is invoked by the upgrade framework to apply upgrade actions
     * to the workspace. A workspace upgrade participant is not allowed to 
     * modify any project resources. To do that, a project upgrade participant
     * needs to be written.
     * 
     * @param monitor the progress monitor, or <code>null</code> if progress
     *   reporting and ability to cancel is not necessary
     * @return true if the workspace is ready after upgrade and false if a restart is required
     * @throws CoreException if failed for any reason
     */
    
    boolean execute( IProgressMonitor monitor ) throws CoreException;

}
