/******************************************************************************
 * Copyright (c) 2016 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 ******************************************************************************/

package oracle.eclipse.tools.common.upgrade.internal;

import static org.eclipse.sapphire.ui.forms.swt.GridLayoutUtil.gdfill;
import static org.eclipse.sapphire.ui.forms.swt.GridLayoutUtil.gdhfill;
import static org.eclipse.sapphire.ui.forms.swt.GridLayoutUtil.gdvindent;
import static org.eclipse.sapphire.ui.forms.swt.GridLayoutUtil.gdwhint;

import java.util.ArrayList;
import java.util.Collections;
import java.util.Comparator;
import java.util.Set;

import org.eclipse.core.resources.IProject;
import org.eclipse.osgi.util.NLS;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.List;

/**
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

public final class UpgradeNoticePanel 

    extends Composite
    
{
    private final Label noticeLabel;
    private final List projects;
    
    public UpgradeNoticePanel( final Composite parent, 
                               final int style ) 
    {
        super( parent, style );
        
        setLayout( new GridLayout( 1, false ) );

        this.noticeLabel = new Label( this, SWT.WRAP );
        this.noticeLabel.setLayoutData( gdwhint( gdhfill(), 350 ) );
        this.noticeLabel.setText( Resources.upgradeNoticeMessage );
        
        final Color bgcolor
            = Display.getCurrent().getSystemColor( SWT.COLOR_WIDGET_BACKGROUND );
        
        this.projects = new List( this, SWT.BORDER | SWT.V_SCROLL );
        this.projects.setLayoutData( gdvindent( gdfill(), 5 ) );
        this.projects.setBackground( bgcolor );
    }
    
    public void setProjects( final Set<IProject> projects )
    {
        this.projects.removeAll();
        
        final ArrayList<IProject> sortedList = new ArrayList<IProject>( projects );
        
        final Comparator<IProject> comparator = new Comparator<IProject>()
        {
            public int compare( final IProject pj1,
                                final IProject pj2 )
            {
                return pj1.getName().compareToIgnoreCase( pj2.getName() );
            }
        };

        Collections.sort( sortedList, comparator );
        
        for( IProject proj : sortedList )
        {
            this.projects.add( proj.getName() );
        }
    }

    private static final class Resources
    
        extends NLS
        
    {
        public static String upgradeNoticeMessage;
        
        static
        {
            initializeMessages( UpgradeNoticePanel.class.getName(), 
                                Resources.class );
        }
    }
    
}
