/******************************************************************************
 * Copyright (c) 2016 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 ******************************************************************************/

package oracle.eclipse.tools.common.upgrade.internal;

import java.util.Set;

import org.eclipse.core.resources.IProject;
import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.osgi.util.NLS;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.help.IWorkbenchHelpSystem;

/**
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

public final class UpgradeWizardPage

    extends WizardPage
    
{
    private final Set<IProject> projects;
    
    public UpgradeWizardPage( final Set<IProject> projects )
    {
        super( "upgrade.notice.page" ); //$NON-NLS-1$

        setTitle( Resources.pageTitle );
        setDescription( Resources.pageDescription );
        
        this.projects = projects;
    }

    public void createControl( final Composite parent ) 
    {
        final UpgradeNoticePanel panel = new UpgradeNoticePanel( parent, SWT.NONE );
        panel.setProjects( this.projects );
        
        final IWorkbenchHelpSystem h = PlatformUI.getWorkbench().getHelpSystem();
        h.setHelp( panel, UpgradePlugin.UPGRADE_WIZARD_FIRST_PAGE_HELP_CONTEXT_ID );

        setControl( panel );
    }
    
    private static final class Resources
    
        extends NLS
        
    {
        public static String pageTitle;
        public static String pageDescription;
        
        static
        {
            initializeMessages( UpgradeWizardPage.class.getName(), 
                                Resources.class );
        }
    }

}
