/*
 * Copyright (c) 2011 Oracle and/or its affiliates. All rights reserved.
 *
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *     Oracle
 */
package oracle.eclipse.tools.glassfish.ui.serverview.actions;

import java.net.URL;

import org.eclipse.jface.action.Action;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.TreeSelection;
import org.eclipse.swt.widgets.Event;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.browser.IWebBrowser;
import org.eclipse.ui.browser.IWorkbenchBrowserSupport;

import oracle.eclipse.tools.glassfish.GlassFishServer;
import oracle.eclipse.tools.glassfish.GlassFishServerBehaviour;
import oracle.eclipse.tools.glassfish.GlassfishToolsPlugin;
import oracle.eclipse.tools.glassfish.ui.serverview.DeployedWebServicesNode;
import oracle.eclipse.tools.glassfish.ui.serverview.WebServiceNode;
import oracle.eclipse.tools.glassfish.utils.Utils;

public 	class TestWebServiceAction extends Action {
	ISelection selection;

	public TestWebServiceAction(ISelection selection) {
		setText("Test Web Service in Browser");


		this.selection = selection;
	}

	public void runWithEvent(Event event) {
		if (selection instanceof TreeSelection) {
			TreeSelection ts = (TreeSelection) selection;
			Object obj = ts.getFirstElement();
			if (obj instanceof WebServiceNode) {
				final WebServiceNode module = (WebServiceNode) obj;
				final DeployedWebServicesNode target = (DeployedWebServicesNode) module
						.getParent();

				try {
					final GlassFishServerBehaviour be = target.getServer()
							.getServerBehaviourAdapter();

					IWorkbenchBrowserSupport browserSupport = PlatformUI
							.getWorkbench().getBrowserSupport();
					IWebBrowser browser = browserSupport
							.createBrowser(
									IWorkbenchBrowserSupport.LOCATION_BAR
											| IWorkbenchBrowserSupport.NAVIGATION_BAR,
									null, null, null);
					GlassFishServer server= be.getGlassfishServerDelegate();
			         String host = server.getServer().getHost();
			         int port = server.getPort();

			         String url = Utils.getHttpListenerProtocol(host,port)+"://"+ host+":"+port+ "/"+module.getWSInfo().getTestURL();
					browser.openURL(new URL(url));

				} catch (Exception e) {
					GlassfishToolsPlugin.logMessage("Error opening browser: "
							+ e.getMessage());
				}
			}
			super.run();
		}
	}

	@Override
	public void run() {
		this.runWithEvent(null);
	}

}
