package oracle.eclipse.tools.glassfish.internal;

import java.io.IOException;
import java.util.Set;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.sapphire.util.SetFactory;

import oracle.eclipse.tools.common.upgrade.IWorkspaceUpgradeParticipant;
import oracle.eclipse.tools.glassfish.GlassFishRuntime;
import oracle.eclipse.tools.glassfish.GlassfishToolsPlugin;
import oracle.eclipse.tools.util.WtpRuntimesMetadata;

public final class GlassFishRuntimeWorkspaceUpgradeParticipant implements IWorkspaceUpgradeParticipant
{
    private static final Set<String> OLD_TYPES;
    
    static
    {
        final SetFactory<String> oldTypesSetFactory = SetFactory.start();
        
        oldTypesSetFactory.add( "org.glassfish.jst.server.runtime.glassfish31" );
        oldTypesSetFactory.add( "org.glassfish.jst.server.runtime.glassfish4" );
        
        OLD_TYPES = oldTypesSetFactory.result();
    }
    
    public boolean check() throws CoreException
    {
        try
        {
            final WtpRuntimesMetadata metadata = new WtpRuntimesMetadata();
            
            for( final WtpRuntimesMetadata.Runtime runtime : metadata.runtimes() )
            {
                if( OLD_TYPES.contains( runtime.getRuntimeType() ) )
                {
                    return true;
                }
            }
            
            return false;
        }
        catch( final IOException e )
        {
            throw new CoreException( GlassfishToolsPlugin.createErrorStatus( e ) );
        }
    }    
    
    public boolean execute( final IProgressMonitor monitor ) throws CoreException
    {
        try
        {
            final WtpRuntimesMetadata metadata = new WtpRuntimesMetadata();
            
            for( final WtpRuntimesMetadata.Runtime runtime : metadata.runtimes() )
            {
                if( OLD_TYPES.contains( runtime.getRuntimeType() ) )
                {
                    runtime.setRuntimeType( GlassFishRuntime.TYPE_ID );
                }
            }
            
            metadata.save();
        }
        catch( final IOException e )
        {
            throw new CoreException( GlassfishToolsPlugin.createErrorStatus( e ) );
        }
        
        return true;
    }

}
