package oracle.eclipse.tools.glassfish.internal;

import java.io.IOException;
import java.util.Set;

import org.eclipse.core.runtime.CoreException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.sapphire.util.SetFactory;

import oracle.eclipse.tools.common.upgrade.IWorkspaceUpgradeParticipant;
import oracle.eclipse.tools.glassfish.GlassFishServer;
import oracle.eclipse.tools.glassfish.GlassfishToolsPlugin;
import oracle.eclipse.tools.util.WtpServersMetadata;

public final class GlassFishServerWorkspaceUpgradeParticipant implements IWorkspaceUpgradeParticipant
{
    private static final Set<String> OLD_TYPES;
    
    static
    {
        final SetFactory<String> oldTypesSetFactory = SetFactory.start();
        
        oldTypesSetFactory.add( "org.glassfish.jst.server.glassfish31" );
        oldTypesSetFactory.add( "org.glassfish.jst.server.glassfish4" );
        
        OLD_TYPES = oldTypesSetFactory.result();
    }
    
    public boolean check() throws CoreException
    {
        try
        {
            final WtpServersMetadata prefs = new WtpServersMetadata();
            
            for( final WtpServersMetadata.Server server : prefs.servers() )
            {
                if( OLD_TYPES.contains( server.getServerType() ) )
                {
                    return true;
                }
            }
            
            return false;
        }
        catch( final IOException e )
        {
            throw new CoreException( GlassfishToolsPlugin.createErrorStatus( e ) );
        }
    }    
    
    public boolean execute( final IProgressMonitor monitor ) throws CoreException
    {
        try
        {
            final WtpServersMetadata metadata = new WtpServersMetadata();
            
            for( final WtpServersMetadata.Server server : metadata.servers() )
            {
                if( OLD_TYPES.contains( server.getServerType() ) )
                {
                    server.setServerType( GlassFishServer.TYPE_ID );
                }
            }
        
            metadata.save();
        }
        catch( final IOException e )
        {
            throw new CoreException( GlassfishToolsPlugin.createErrorStatus( e ) );
        }
        
        return false;
    }

}
