package oracle.eclipse.tools.glassfish.log;

import java.io.BufferedReader;
import java.io.IOException;
import java.io.InputStreamReader;
import java.nio.charset.StandardCharsets;
import java.util.concurrent.CountDownLatch;

import org.eclipse.ui.console.MessageConsoleStream;
import org.glassfish.tools.ide.server.FetchLog;

public class LogReader implements Runnable {
	
	private FetchLog logFetcher;
	private MessageConsoleStream output;
	private CountDownLatch latch;
	private ILogFilter filter;

	LogReader(FetchLog logFetcher, MessageConsoleStream outputStream, CountDownLatch latch, ILogFilter filter) {
		this.logFetcher = logFetcher;
		this.output = outputStream;
		this.latch = latch;
		this.filter = filter;
	}

	@Override
	public void run()
	{
		try
		{
		    BufferedReader reader = new BufferedReader( new InputStreamReader( logFetcher.getInputStream(), StandardCharsets.UTF_8 ) );
		    
			for( String line = null; (line = reader.readLine()) != null; )
			{
				//System.out.println(line);
				line = filter.process(line);
				if (line != null) {
					//output.println("line:");
					output.println(line);
				}
			}
			output.flush();
		} catch (IOException e) {
			//this happens when input stream is closed, no need to print
			//e.printStackTrace();
		} finally {
			//System.out.println("end, closing streams...");
			logFetcher.close();
			latch.countDown();
		}
	}

	public void stop() {
		//System.out.println("stop called...");
		logFetcher.close();
	}

}

