/******************************************************************************
 * Copyright (c) 2014 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 ******************************************************************************/

package oracle.eclipse.tools.javaee.doc.integration;

import java.net.URL;

import org.eclipse.core.runtime.FileLocator;
import org.eclipse.core.runtime.ILog;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Platform;
import org.eclipse.core.runtime.Status;
import org.eclipse.jface.action.ContributionItem;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.swt.SWT;
import org.eclipse.swt.graphics.Image;
import org.eclipse.swt.widgets.Event;
import org.eclipse.swt.widgets.Listener;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.swt.widgets.MenuItem;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.browser.IWebBrowser;
import org.eclipse.ui.browser.IWorkbenchBrowserSupport;
import org.osgi.framework.Bundle;

/**
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

public final class DocMenuContributionItem extends ContributionItem
{
    private Image image;
    
    @Override
    public void fill( final Menu parent, int index )
    {
        for( int i = 7; i >= 5; i--, index++ )
        {
            add( parent, index, i );
        }
    }
    
    private void add( final Menu parent, final int index, final int version )
    {
        final String bundleId = "oracle.eclipse.tools.javaee.v" + version + ".doc";
        final Bundle bundle = Platform.getBundle( bundleId );
        
        if( bundle != null )
        {
            final MenuItem item;
            
            if( index >= 0 )
            {
                item = new MenuItem( parent, SWT.PUSH, index );
            }
            else
            {
                item = new MenuItem( parent, SWT.PUSH );
            }
            
            item.setText( "Java EE " + version + " Documentation" );
            
            if( this.image == null )
            {
                final Bundle self = Platform.getBundle( "oracle.eclipse.tools.javaee.doc.integration" );
                this.image = ImageDescriptor.createFromURL( self.getEntry( "/images/JavaHelp.png" ) ).createImage();
            }
            
            item.setImage( this.image );
            
            item.addListener
            (
                SWT.Selection, 
                new Listener()
                {
                    @Override
                    public void handleEvent( final Event event )
                    {
                        try
                        {
                            final IWorkbenchBrowserSupport browserSupport = PlatformUI.getWorkbench().getBrowserSupport();
                            final IWebBrowser browser = browserSupport.createBrowser( IWorkbenchBrowserSupport.LOCATION_BAR | IWorkbenchBrowserSupport.NAVIGATION_BAR, null, null, null );
                            final URL url = FileLocator.resolve( bundle.getEntry( version == 5 ? "/content/api/index.html" : "/content/index.html" ) );
                            browser.openURL( url );
                        }
                        catch( Exception e )
                        {
                            final ILog log = Platform.getLog( bundle );
                            log.log( new Status( IStatus.ERROR, bundleId, IStatus.OK, e.getMessage() + "", e ) );
                        }
                    }
                }
            );
        }
    }
    
    public boolean isDynamic()
    {
        return true;
    }

    @Override
    public void dispose()
    {
        if( this.image != null )
        {
            this.image.dispose();
        }
        
        super.dispose();
    }
    
}
