/******************************************************************************
 * Copyright (c) 2016 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 ******************************************************************************/

package oracle.eclipse.tools.util;

/**
 * Miscellaneous utility functions. 
 * 
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

public final class MiscUtil
{
    /**
     * Validates that the parameter is not <code>null</code>. If the parameter is <code>null</code>, 
     * an {@see IllegalArgumentException} is thrown, otherwise the parameter object is returned 
     * back to the caller. 
     * 
     * @param obj the object to check
     * @return the input object
     * @throws IllegalArgumentException if the parameter is <code>null</code>
     */
    
    public static <T> T checkNotNull( final T obj )
    {
        if( obj == null )
        {
            throw new IllegalArgumentException();
        }
        
        return obj;
    }
    
    private MiscUtil() {}
    
}
