/******************************************************************************
 * Copyright (c) 2016 Oracle
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 ******************************************************************************/

package oracle.eclipse.tools.util.internal;

import org.eclipse.core.runtime.ILog;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Platform;
import org.eclipse.core.runtime.Status;
import org.osgi.framework.Bundle;

/**
 * @author <a href="mailto:konstantin.komissarchik@oracle.com">Konstantin Komissarchik</a>
 */

public final class UtilPlugin
{
    public static final String SYMBOLIC_NAME = "oracle.eclipse.tools.util";
    public static final Bundle BUNDLE = Platform.getBundle( SYMBOLIC_NAME );
    private static final ILog LOG = Platform.getLog( BUNDLE );
    
    public static void logError( final String message )
    {
        log( createErrorStatus( message ) );
    }

    public static void log( final Exception e )
    {
        log( createErrorStatus( e ) );
    }

    public static void log( final IStatus status )
    {
        LOG.log( status );
    }
    
    public static IStatus createErrorStatus( final String message )
    {
        return new Status( IStatus.ERROR, SYMBOLIC_NAME, 0, message, null );
    }
    
    public static IStatus createErrorStatus( final Exception e )
    {
        return new Status( IStatus.ERROR, SYMBOLIC_NAME, 0, e.getMessage() + "", e );
    }
    
}
